@@ -9,12 +9,10 @@ import (
 
 	"github.com/projectdiscovery/gologger"
 	"github.com/projectdiscovery/gologger/formatter"
-	"github.com/projectdiscovery/gologger/levels"
 	"github.com/projectdiscovery/katana/pkg/types"
 	"github.com/projectdiscovery/katana/pkg/utils"
 	errorutil "github.com/projectdiscovery/utils/errors"
 	fileutil "github.com/projectdiscovery/utils/file"
-	logutil "github.com/projectdiscovery/utils/log"
 	"gopkg.in/yaml.v3"
 )
 
@@ -27,8 +25,11 @@ func validateOptions(options *types.Options) error {
 		return errorutil.New("no inputs specified for crawler")
 	}
 
-	if options.Headless && options.Passive {
-		return errorutil.New("headless mode (-headless) and passive mode (-passive) cannot be used together")
+	// Disabling automatic form fill (-aff) for headless navigation due to incorrect implementation.
+	// Form filling should be handled via headless actions within the page context
+	if options.Headless && options.AutomaticFormFill {
+		options.AutomaticFormFill = false
+		gologger.Info().Msgf("Automatic form fill (-aff) has been disabled for headless navigation.")
 	}
 
 	if (options.HeadlessOptionalArguments != nil || options.HeadlessNoSandbox || options.SystemChromePath != "") && !options.Headless {
@@ -110,21 +111,6 @@ func normalizeInput(value string) string {
 	return strings.TrimSpace(value)
 }
 
-// configureOutput configures the output logging levels to be displayed on the screen
-func configureOutput(options *types.Options) {
-	if options.Silent {
-		gologger.DefaultLogger.SetMaxLevel(levels.LevelSilent)
-	} else if options.Verbose {
-		gologger.DefaultLogger.SetMaxLevel(levels.LevelWarning)
-	} else if options.Debug {
-		gologger.DefaultLogger.SetMaxLevel(levels.LevelDebug)
-	} else {
-		gologger.DefaultLogger.SetMaxLevel(levels.LevelInfo)
-	}
-
-	logutil.DisableDefaultLogger()
-}
-
 func initExampleFormFillConfig() error {
 	homedir, err := os.UserHomeDir()
 	if err != nil {
