@@ -2,6 +2,7 @@ package parser
 
 import (
 	"mime/multipart"
+	"net/http"
 	"strings"
 
 	"github.com/PuerkitoBio/goquery"
@@ -63,6 +64,7 @@ var responseParsers = []responseParser{
 	{bodyParser, bodyMetaContentTagParser},
 	{bodyParser, bodyHtmlManifestTagParser},
 	{bodyParser, bodyHtmlDoctypeTagParser},
+	{bodyParser, bodyHtmxAttrParser},
 
 	// custom field regex parser
 	{bodyParser, customFieldRegexParser},
@@ -397,7 +399,7 @@ func bodyVideoTagParser(resp *navigation.Response) (navigationRequests []*naviga
 	return
 }
 
-// bodyButtonFormactionTagParser parses blockquote cite tag from response
+// bodyBlockquoteCiteTagParser parses blockquote cite tag from response
 func bodyBlockquoteCiteTagParser(resp *navigation.Response) (navigationRequests []*navigation.Request) {
 	resp.Reader.Find("blockquote[cite]").Each(func(i int, item *goquery.Selection) {
 		src, ok := item.Attr("cite")
@@ -527,16 +529,16 @@ func bodyFormTagParser(resp *navigation.Response) (navigationRequests []*navigat
 			multipartWriter = multipart.NewWriter(&sb)
 		}
 
-		// Get the form field suggestions for all inputs
-		formInputs := []utils.FormInput{}
-		item.Find("input").Each(func(index int, item *goquery.Selection) {
+		// Get the form field suggestions for all elements in the form
+		formFields := []interface{}{}
+		item.Find("input, select, textarea").Each(func(index int, item *goquery.Selection) {
 			if len(item.Nodes) == 0 {
 				return
 			}
-			formInputs = append(formInputs, utils.ConvertGoquerySelectionToFormInput(item))
+			formFields = append(formFields, utils.ConvertGoquerySelectionToFormField(item))
 		})
 
-		dataMap := utils.FormInputFillSuggestions(formInputs)
+		dataMap := utils.FormFillSuggestions(formFields)
 		dataMap.Iterate(func(key, value string) bool {
 			if key == "" {
 				return true
@@ -600,6 +602,44 @@ func bodyMetaContentTagParser(resp *navigation.Response) (navigationRequests []*
 	return
 }
 
+func bodyHtmxAttrParser(resp *navigation.Response) (navigationRequests []*navigation.Request) {
+	// exclude hx-delete
+	resp.Reader.Find("[hx-get],[hx-post],[hx-put],[hx-patch]").Each(func(i int, item *goquery.Selection) {
+		req := &navigation.Request{
+			RootHostname: resp.RootHostname,
+			Depth:        resp.Depth,
+			Source:       resp.Resp.Request.URL.String(),
+			Tag:          "htmx",
+		}
+
+		if hxGet, ok := item.Attr("hx-get"); ok && hxGet != "" {
+			req.Method = http.MethodGet
+			req.URL = resp.AbsoluteURL(hxGet)
+			req.Attribute = "hx-get"
+			navigationRequests = append(navigationRequests, req)
+		}
+		if hxPost, ok := item.Attr(("hx-post")); ok && hxPost != "" {
+			req.Method = http.MethodPost
+			req.URL = resp.AbsoluteURL(hxPost)
+			req.Attribute = "hx-post"
+			navigationRequests = append(navigationRequests, req)
+		}
+		if hxPut, ok := item.Attr(("hx-put")); ok && hxPut != "" {
+			req.Method = http.MethodPut
+			req.URL = resp.AbsoluteURL(hxPut)
+			req.Attribute = "hx-put"
+			navigationRequests = append(navigationRequests, req)
+		}
+		if hxPatch, ok := item.Attr(("hx-patch")); ok && hxPatch != "" {
+			req.Method = http.MethodPatch
+			req.URL = resp.AbsoluteURL(hxPatch)
+			req.Attribute = "hx-patch"
+			navigationRequests = append(navigationRequests, req)
+		}
+	})
+	return
+}
+
 // -------------------------------------------------------------------------
 // Begin JS Regex based parsers
 // -------------------------------------------------------------------------
