@@ -21,7 +21,7 @@ type CrawlerOptions struct {
 	// OutputWriter is the interface for writing output
 	OutputWriter output.Writer
 	// RateLimit is a mechanism for controlling request rate limit
-	RateLimit ratelimit.Limiter
+	RateLimit *ratelimit.Limiter
 	// Options contains the user specified configuration options
 	Options *Options
 	// ExtensionsValidator is a validator for file extensions
@@ -39,6 +39,7 @@ type CrawlerOptions struct {
 // NewCrawlerOptions creates a new crawler options structure
 // from user specified options.
 func NewCrawlerOptions(options *Options) (*CrawlerOptions, error) {
+	options.ConfigureOutput()
 	extensionsValidator := extensions.NewValidator(options.ExtensionsMatch, options.ExtensionFilter)
 
 	dialerOpts := fastdialer.DefaultOptions
@@ -68,6 +69,8 @@ func NewCrawlerOptions(options *Options) (*CrawlerOptions, error) {
 		Fields:                options.Fields,
 		StoreFields:           options.StoreFields,
 		StoreResponseDir:      options.StoreResponseDir,
+		NoClobber:             options.NoClobber,
+		StoreFieldDir:         options.StoreFieldDir,
 		OmitRaw:               options.OmitRaw,
 		OmitBody:              options.OmitBody,
 		FieldConfig:           options.FieldConfig,
@@ -109,9 +112,9 @@ func NewCrawlerOptions(options *Options) (*CrawlerOptions, error) {
 	}
 
 	if options.RateLimit > 0 {
-		crawlerOptions.RateLimit = *ratelimit.New(context.Background(), uint(options.RateLimit), time.Second)
+		crawlerOptions.RateLimit = ratelimit.New(context.Background(), uint(options.RateLimit), time.Second)
 	} else if options.RateLimitMinute > 0 {
-		crawlerOptions.RateLimit = *ratelimit.New(context.Background(), uint(options.RateLimitMinute), time.Minute)
+		crawlerOptions.RateLimit = ratelimit.New(context.Background(), uint(options.RateLimitMinute), time.Minute)
 	}
 
 	wappalyze, err := wappalyzer.New()
